/* --------------------------------------------------------------
 order_details_controller.js 2016-11-09
 Gambio GmbH
 http://www.gambio.de
 Copyright (c) 2016 Gambio GmbH
 Released under the GNU General Public License (Version 2)
 [http://www.gnu.org/licenses/gpl-2.0.html]
 --------------------------------------------------------------
 */

/**
 * ## Order Details Controller
 *
 * This controller will handle the compatibility order details wrapper.
 *
 * @module Compatibility/order_details_controller
 */
gx.compatibility.module(
	'order_details_controller',
	
	[],
	
	/**  @lends module:Compatibility/order_details_controller */
	
	function(data) {
		
		'use strict';
		
		// ------------------------------------------------------------------------
		// VARIABLES DEFINITION
		// ------------------------------------------------------------------------
		
		var
			/**
			 * Module Selector
			 *
			 * @var {object}
			 */
			$this = $(this),
			
			/**
			 * Default Options
			 *
			 * @type {object}
			 */
			defaults = {},
			
			/**
			 * Final Options
			 *
			 * @var {object}
			 */
			options = $.extend(true, {}, defaults, data),
			
			/**
			 * Module Object
			 *
			 * @type {object}
			 */
			module = {};
		
		// ------------------------------------------------------------------------
		// FUNCTIONS
		// ------------------------------------------------------------------------
		
		/**
		 * Create Invoice Click Event 
		 * 
		 * This callback will make sure that the invoice is created and then make a page reload. 
		 * 
		 * @param {jQuery.Event} event
		 */
		var _onCreateInvoiceClick = function(event) {
			event.preventDefault(); 
			
			var downloadPdfWindow = window.open('about:blank'); 
			var url = event.target.getAttribute('href') + '&ajax=1';
			
			$.getJSON(url)
				.done(function(response) {
					downloadPdfWindow.location = jse.core.config.get('appUrl') + '/admin/request_port.php?' + $.param({
							module: 'OrderAdmin', 
							action: 'showPdf', 
							type: 'invoice', 
							invoice_id: response.invoiceId
						});
					location.reload();
				})
				.fail(function(jqXHR, textStatus, errorThrown) {
					downloadPdfWindow.close();
				});
		};
		
		/**
		 * Create Packing Slip Click Event
		 *
		 * This callback will make sure that the packing slip is created and then make a page reload.
		 *
		 * @param {jQuery.Event} event
		 */
		var _onCreatePackingSlipClick = function(event) {
			event.preventDefault();
			
			var downloadPdfWindow = window.open('about:blank');
			var url = event.target.getAttribute('href') + '&ajax=1';
			
			$.getJSON(url)
				.done(function(response) {
					downloadPdfWindow.location = jse.core.config.get('appUrl') + '/admin/request_port.php?' + $.param({
							module: 'OrderAdmin',
							action: 'showPdf',
							type: 'packingslip',
							file: response.filename + '__' + response.filenameSuffix
						});
					location.reload();
				})
				.fail(function(jqXHR, textStatus, errorThrown) {
					downloadPdfWindow.close();
				});
		};
		
		/**
		 * Open order status modal on click on elements with class add-order-status
		 *
		 * @param {jQuery.Event} event
		 */
		var _onAddOrderStatusClick = function(event) {
			event.preventDefault();
			$('.update-order-status').trigger('click');
		};
		
		// ------------------------------------------------------------------------
		// INITIALIZATION
		// ------------------------------------------------------------------------
		
		module.init = function(done) {
			$('.message_stack_container').addClass('breakpoint-large');
			
			$this
				.on('click', '.add-order-status', _onAddOrderStatusClick)
				.on('click', '.create-invoice', _onCreateInvoiceClick)
				.on('click', '.create-packing-slip', _onCreatePackingSlipClick);
			
			done();
		};
		
		return module;
	});
